@@ -1,6 +1,7 @@
 //! Voter which locks up governance tokens for a user-provided duration in exchange for increased voting power.
 #![deny(rustdoc::all)]
 #![allow(rustdoc::missing_doc_code_examples)]
+#![deny(clippy::unwrap_used)]
 
 pub mod macros;
 
@@ -27,8 +28,7 @@ pub mod locked_voter {
     /// Creates a new [Locker].
     #[access_control(ctx.accounts.validate())]
     pub fn new_locker(ctx: Context<NewLocker>, _bump: u8, params: LockerParams) -> Result<()> {
-        ctx.accounts
-            .new_locker(*unwrap_int!(ctx.bumps.get("locker")), params)
+        ctx.accounts.new_locker(unwrap_bump!(ctx, "locker"), params)
     }
 
     /// Creates a new [Escrow] for an account.
@@ -38,24 +38,55 @@ pub mod locked_voter {
     /// linearly proportional to the amount of votes given.
     #[access_control(ctx.accounts.validate())]
     pub fn new_escrow(ctx: Context<NewEscrow>, _bump: u8) -> Result<()> {
-        ctx.accounts
-            .new_escrow(*unwrap_int!(ctx.bumps.get("escrow")))
+        ctx.accounts.new_escrow(unwrap_bump!(ctx, "escrow"))
     }
 
     /// Stakes `amount` tokens into the [Escrow].
+    /// WARNING: if the program has a whitelist, one should use [crate::locked_voter::lock_with_whitelist] instead.
+    /// This version of the instruction is deprecated.
     #[access_control(ctx.accounts.validate())]
     pub fn lock<'info>(
         ctx: Context<'_, '_, '_, 'info, Lock<'info>>,
         amount: u64,
         duration: i64,
     ) -> Result<()> {
+        msg!("Warning: this instruction is deprecated in favor of `lock_with_whitelist`, `lock_with_whitelist_entry`, or `lock_permissionless`. Please update your Tribeca SDK.");
         if ctx.accounts.locker.params.whitelist_enabled {
             ctx.accounts.check_whitelisted(ctx.remaining_accounts)?;
         }
-
         ctx.accounts.lock(amount, duration)
     }
 
+    /// Stakes `amount` tokens into the [Escrow], if there is a whitelist.
+    #[access_control(ctx.accounts.validate())]
+    pub fn lock_with_whitelist<'info>(
+        ctx: Context<'_, '_, '_, 'info, LockWithWhitelist<'info>>,
+        amount: u64,
+        duration: i64,
+    ) -> Result<()> {
+        instructions::lock_with_whitelist::handler(ctx, amount, duration)
+    }
+
+    /// Stakes `amount` tokens into the [Escrow] via CPI by using the provided [LockerWhitelistEntry].
+    #[access_control(ctx.accounts.validate())]
+    pub fn lock_with_whitelist_entry<'info>(
+        ctx: Context<'_, '_, '_, 'info, LockWithWhitelistEntry<'info>>,
+        amount: u64,
+        duration: i64,
+    ) -> Result<()> {
+        instructions::lock_with_whitelist_entry::handler(ctx, amount, duration)
+    }
+
+    /// Stakes `amount` tokens into the [Escrow] if there is no whitelist.
+    #[access_control(ctx.accounts.validate())]
+    pub fn lock_permissionless<'info>(
+        ctx: Context<'_, '_, '_, 'info, Lock<'info>>,
+        amount: u64,
+        duration: i64,
+    ) -> Result<()> {
+        instructions::lock_permissionless::handler(ctx, amount, duration)
+    }
+
     /// Exits the DAO; i.e., withdraws all staked tokens in an [Escrow] if the [Escrow] is unlocked.
     #[access_control(ctx.accounts.validate())]
     pub fn exit(ctx: Context<Exit>) -> Result<()> {
@@ -93,7 +124,7 @@ pub mod locked_voter {
         _bump: u8,
     ) -> Result<()> {
         ctx.accounts
-            .approve_program_lock_privilege(*unwrap_int!(ctx.bumps.get("whitelist_entry")))
+            .approve_program_lock_privilege(unwrap_bump!(ctx, "whitelist_entry"))
     }
 
     /// Close a [LockerWhitelistEntry] revoking program's CPI privilege.
@@ -116,8 +147,12 @@ pub enum ErrorCode {
     RefreshCannotShorten,
     #[msg("Escrow has not ended.")]
     EscrowNotEnded,
-    #[msg("Program whitelist enabled; please provide whitelist entry and instructions sysvar")]
+    #[msg("Program whitelist enabled; please provide whitelist entry and instructions sysvar or use the 'lock_with_whitelist' instruction.")]
     MustProvideWhitelist,
     #[msg("CPI caller not whitelisted for escrow owner to invoke lock instruction.")]
     EscrowOwnerNotWhitelisted,
+    #[msg("Must call `lock_with_whitelist_entry` to lock via CPI.")]
+    MustCallLockWithWhitelistEntry,
+    #[msg("Must call `lock_permissionless` since this DAO does not have a CPI whitelist.")]
+    MustCallLockPermissionless,
 }
